@@ -378,7 +378,10 @@ class Clone(Interface):
                 # Note, that we didn't allow deviating from git's default
                 # behavior WRT a submodule's name vs its path when we made this
                 # a new subdataset.
-                subds_name = path.relative_to(ds.pathobj)
+                # all pathobjs involved are platform paths, but the
+                # default submodule name equals the relative path
+                # in posix conventions, hence .as_posix()
+                subds_name = path.relative_to(ds.pathobj).as_posix()
                 ds.repo.call_git(
                     ['config',
                      '--file',
@@ -910,8 +913,12 @@ def configure_origins(cfgds, probeds, label=None, remote="origin"):
     # given the clone source is a local dataset, we can have a
     # cheap look at it, and configure its own `remote` as a remote
     # (if there is any), and benefit from additional annex availability
-    yield from configure_origins(
-        cfgds,
-        Dataset(probeds.pathobj / origin_url),
-        label=label + 1,
-        remote=remote)
+    # But first check if we would recurse into the same dataset
+    # to prevent infinite recursion (see gh-7721)
+    next_dataset_path = probeds.pathobj / origin_url
+    if next_dataset_path.resolve() != probeds.pathobj.resolve():
+        yield from configure_origins(
+            cfgds,
+            Dataset(next_dataset_path),
+            label=label + 1,
+            remote=remote)
