@@ -13,11 +13,9 @@
 __docformat__ = 'restructuredtext'
 
 # Not really worth to be there but it is ATM, so let's use that
-from datalad.api import (
-    shell_completion
-)
+from datalad.api import shell_completion
 from datalad.cmd import WitlessRunner
-from datalad.tests.utils import (
+from datalad.tests.utils_pytest import (
     assert_cwd_unchanged,
     eq_,
     skip_if_on_windows,
@@ -42,4 +40,4 @@ def test_shell_completion_source():
     # ideally we should feed that shell with TAB to see the result of completion but
     # yoh sees no easy way ATM, and googled up
     # https://stackoverflow.com/questions/9137245/unit-test-for-bash-completion-script
-    # requires too much enthusiasm toward this goal.
\ No newline at end of file
+    # requires too much enthusiasm toward this goal.
