@@ -1,5 +1,5 @@
 # emacs: -*- mode: python; py-indent-offset: 4; tab-width: 4; indent-tabs-mode: nil -*-
-# ex: set sts=4 ts=4 sw=4 noet:
+# ex: set sts=4 ts=4 sw=4 et:
 # ## ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ##
 #
 #   See COPYING file distributed along with the datalad package for the
@@ -12,19 +12,28 @@ from unittest.mock import patch
 from datalad.support.annexrepo import AnnexRepo
 from datalad.support.gitrepo import GitRepo
 from datalad.support.repodates import check_dates
-from datalad.tests.utils import assert_equal, assert_false, \
-    assert_in, assert_not_in, assert_raises, eq_, ok_, \
-    set_date, with_tempfile, with_tree
+from datalad.tests.utils_pytest import (
+    assert_equal,
+    assert_false,
+    assert_in,
+    assert_not_in,
+    assert_raises,
+    eq_,
+    ok_,
+    set_date,
+    with_tempfile,
+    with_tree,
+)
 
 
 @with_tempfile(mkdir=True)
-def test_check_dates_empty_repo(path):
+def test_check_dates_empty_repo(path=None):
     assert_false(check_dates(GitRepo(path, create=True))["objects"])
 
 
 @with_tree(tree={"foo": "foo content",
                  "bar": "bar content"})
-def test_check_dates(path):
+def test_check_dates(path=None):
     refdate = 1218182889
 
     with set_date(refdate - 1):
