@@ -5,4 +5,7 @@ import sys
 
 if __name__ == "__main__":
     x = str(list(range(1000))) + '\n'
-    [(sys.stdout.writelines(x), sys.stderr.writelines(x)) for i in range(100)]
+    for i in range(100):
+        s = "%d " % i + x
+        sys.stdout.writelines(s)
+        sys.stderr.writelines(s)
