@@ -9,11 +9,7 @@
 """Tests for test repositories
 
 """
-from datalad.tests.utils_testrepos import (
-    BasicAnnexTestRepo,
-    BasicGitTestRepo,
-)
-from datalad.tests.utils import (
+from datalad.tests.utils_pytest import (
     assert_repo_status,
     ok_,
     ok_file_under_git,
@@ -21,6 +17,10 @@ from datalad.tests.utils import (
     swallow_outputs,
     with_tempfile,
 )
+from datalad.tests.utils_testrepos import (
+    BasicAnnexTestRepo,
+    BasicGitTestRepo,
+)
 
 
 def _test_BasicAnnexTestRepo(repodir):
@@ -47,12 +47,12 @@ def test_BasicAnnexTestRepo_random_location_generated():
 
 
 @with_tempfile()
-def test_BasicAnnexTestRepo(path):
+def test_BasicAnnexTestRepo(path=None):
     _test_BasicAnnexTestRepo(path)
 
 
 @with_tempfile()
-def test_BasicGitTestRepo(path):
+def test_BasicGitTestRepo(path=None):
     trepo = BasicGitTestRepo(path)
     trepo.create()
     assert_repo_status(trepo.path, annex=False)
